==> GraphLab-Create-1.1.tar.gz: GraphLab-Create-1.1/graphlab_util/config.py <==
import os
import time
import logging

class GraphLabConfig:

    __slots__ = ['graphlab_server', 'server_addr', 'server_bin', 'log_dir', 'unity_metric',
                 'mode', 'version', 'librato_user', 'librato_token', 'mixpanel_user',
                 'log_rotation_interval','log_rotation_truncate']

    def __init__(self, server_addr=None):
        if not server_addr:
            server_addr = 'default'
        self.server_addr = server_addr
        gl_root = os.path.abspath(os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', 'graphlab'))
        self.log_rotation_interval = 86400
        self.log_rotation_truncate = 8
        if "GRAPHLAB_UNITY" in os.environ:
            self.server_bin = os.environ["GRAPHLAB_UNITY"]
        elif os.path.exists(os.path.join(gl_root, "unity_server")):
            self.server_bin = os.path.join(gl_root, "unity_server")

        if "GRAPHLAB_LOG_ROTATION_INTERVAL" in os.environ:
            tmp = os.environ["GRAPHLAB_LOG_ROTATION_INTERVAL"]
            try:
                self.log_rotation_interval = int(tmp)
            except:
                logging.getLogger(__name__).warning("GRAPHLAB_LOG_ROTATION_INTERVAL must be an integral value")

        if "GRAPHLAB_LOG_ROTATION_TRUNCATE" in os.environ:
            tmp = os.environ["GRAPHLAB_LOG_ROTATION_TRUNCATE"]
            try:
                self.log_rotation_truncate = int(tmp)
            except:
                logging.getLogger(__name__).warning("GRAPHLAB_LOG_ROTATION_TRUNCATE must be an integral value")

        if "GRAPHLAB_LOG_PATH" in os.environ:
            log_dir = os.environ["GRAPHLAB_LOG_PATH"]
        else:
            log_dir = "/tmp"

        self.log_dir = log_dir
        ts = str(int(time.time()))
        self.unity_metric = os.path.join(log_dir, 'graphlab_metric_' + str(ts) + '.log')

        # Import our unity conf file if it exists, and get the mode from it
        try:
          import graphlab_env
        except ImportError:
          self.graphlab_server = 'http://tarjan.graphlab.com:9292'
          self.mode = 'UNIT'
          self.version = '0.1.desktop'
          self.librato_user = ''
          self.librato_token = ''
          self.mixpanel_user = ''
        else:
          if graphlab_env.mode in ['UNIT', 'DEV', 'QA', 'PROD']:
            self.mode = graphlab_env.mode
          else:
            self.mode = 'PROD'

          self.version = graphlab_env.version
          self.librato_user = graphlab_env.librato_user
          self.librato_token = graphlab_env.librato_token
          self.mixpanel_user = graphlab_env.mixpanel_user
          self.graphlab_server = graphlab_env.graphlab_server

          # NOTE: Remember to update slots if you are adding any config parameters to this file.

    def get_unity_log(self):
        ts = str(int(time.time()))
        return os.path.join(self.log_dir, 'graphlab_server_' + str(ts) + '.log')

DEFAULT_CONFIG = GraphLabConfig()

==> GraphLab-Create-1.2.1.tar.gz: GraphLab-Create-1.2.1/graphlab_util/config.py <==
import os
import time
import logging

class GraphLabConfig:

    __slots__ = ['graphlab_server', 'server_addr', 'server_bin', 'log_dir', 'unity_metric',
                 'mode', 'version', 'librato_user', 'librato_token', 'mixpanel_user',
                 'log_rotation_interval','log_rotation_truncate']

    def __init__(self, server_addr=None):
        if not server_addr:
            server_addr = 'default'
        self.server_addr = server_addr
        gl_root = os.path.abspath(os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', 'graphlab'))
        self.log_rotation_interval = 86400
        self.log_rotation_truncate = 8
        if "GRAPHLAB_UNITY" in os.environ:
            self.server_bin = os.environ["GRAPHLAB_UNITY"]
        elif os.path.exists(os.path.join(gl_root, "unity_server")):
            self.server_bin = os.path.join(gl_root, "unity_server")

        if "GRAPHLAB_LOG_ROTATION_INTERVAL" in os.environ:
            tmp = os.environ["GRAPHLAB_LOG_ROTATION_INTERVAL"]
            try:
                self.log_rotation_interval = int(tmp)
            except:
                logging.getLogger(__name__).warning("GRAPHLAB_LOG_ROTATION_INTERVAL must be an integral value")

        if "GRAPHLAB_LOG_ROTATION_TRUNCATE" in os.environ:
            tmp = os.environ["GRAPHLAB_LOG_ROTATION_TRUNCATE"]
            try:
                self.log_rotation_truncate = int(tmp)
            except:
                logging.getLogger(__name__).warning("GRAPHLAB_LOG_ROTATION_TRUNCATE must be an integral value")

        if "GRAPHLAB_LOG_PATH" in os.environ:
            log_dir = os.environ["GRAPHLAB_LOG_PATH"]
        else:
            log_dir = "/tmp"

        self.log_dir = log_dir
        ts = str(int(time.time()))
        self.unity_metric = os.path.join(log_dir, 'graphlab_metric_' + str(ts) + '.log')

        # Import our unity conf file if it exists, and get the mode from it
        try:
          import graphlab_env
        except ImportError:
          self.graphlab_server = 'http://pws-billing-stage.herokuapp.com'
          self.mode = 'UNIT'
          self.version = '0.1.desktop'
          self.librato_user = ''
          self.librato_token = ''
          self.mixpanel_user = ''
        else:
          if graphlab_env.mode in ['UNIT', 'DEV', 'QA', 'PROD']:
            self.mode = graphlab_env.mode
          else:
            self.mode = 'PROD'

          self.version = graphlab_env.version
          self.librato_user = graphlab_env.librato_user
          self.librato_token = graphlab_env.librato_token
          self.mixpanel_user = graphlab_env.mixpanel_user
          self.graphlab_server = graphlab_env.graphlab_server

          # NOTE: Remember to update slots if you are adding any config parameters to this file.

    def get_unity_log(self):
        ts = str(int(time.time()))
        return os.path.join(self.log_dir, 'graphlab_server_' + str(ts) + '.log')

DEFAULT_CONFIG = GraphLabConfig()
